@@ -1,6 +1,6 @@
 import cro_validate.api.configuration_api as ConfigApi
 
-def get_examples(definition, **kw):
+def get_example_generator(definition, **kw):
 	generator = ConfigApi.get_example_generator_factory().create(definition, **kw)
 	return generator
 
