@@ -36,52 +36,88 @@ class Boolean(Rules.Rule):
 			)
 
 
-class RootModel:
-	a = None
-	b = Schemas.Field(input_name='b', required=False)
-	c = Schemas.Field(input_name='c', definition_name='ChildModel', required=True)
-
-
-class ChildModel:
-	a1 = Schemas.Field(input_name='a1', definition_name='a')
+json_str = '''
+{
+	"a": {
+		"data_type": "Boolean",
+		"default_value": false,
+		"default_value_type": "builtins.bool",
+		"description": "Demo field a.",
+		"rules": [
+			{
+				"config": {},
+				"type": "test.test_example_complex_array_generator.Boolean"
+			}
+		]
+	},
+	"b": {
+		"data_type": "Boolean",
+		"default_value": false,
+		"default_value_type": "builtins.bool",
+		"description": "Demo field b.",
+		"rules": [
+			{
+				"config": {},
+				"type": "test.test_example_complex_array_generator.Boolean"
+			}
+		]
+	},
+	"RootModel": {
+		"data_format": {
+			"load_defaults": true,
+			"model": {
+				"a": {
+					"required": false
+				},
+				"b": {
+					"required": false
+				},
+				"c": {
+					"definition_name": "ChildModel",
+					"required": true
+				}
+			},
+			"model_type": "SchemaDefinition"
+		},
+		"data_format_type": "cro_validate.classes.schema_classes.Schema",
+		"data_type": "Object",
+		"description": "Root model."
+	},
+	"ChildModel": {
+		"data_format": {
+			"load_defaults": true,
+			"model": {
+				"a1": {
+					"definition_name": "a"
+				}
+			},
+			"model_type": "SchemaDefinition"
+		},
+		"data_format_type": "cro_validate.classes.schema_classes.Schema",
+		"data_type": "Object",
+		"description": "Demo model 2."
+	},
+	"RootModelArray": {
+		"data_format": "RootModel",
+		"data_format_type": "builtins.str",
+		"data_type": "Array",
+		"description": "RootModel array."
+	},
+	"ChildModelArray": {
+		"data_format": "ChildModel",
+		"data_format_type": "builtins.str",
+		"data_type": "Array",
+		"description": "ChildModel array."
+	}
+}
+'''
 
 
 def register():
 	DefinitionApi.clear()
 
-	DefinitionApi.register_definition(
-			name='a',
-			data_type=DataType.Boolean,
-			default_value=False,
-			rules=[Boolean()]
-		)
-
-	DefinitionApi.register_definition(
-			name='b',
-			data_type=DataType.Boolean,
-			default_value=False,
-			rules=[Boolean()]
-		)
-
-	DefinitionApi.register_definition(
-			data_type=DataType.Object,
-			data_format=Schemas.Schema(ChildModel)
-		)
-
-	DefinitionApi.register_definition(
-			data_type=DataType.Array,
-			data_format='ChildModel'
-		)
-
-	DefinitionApi.register_definition(
-			data_type=DataType.Object,
-			data_format=Schemas.Schema(RootModel)
-		)
-
-	DefinitionApi.register_definition(
-			data_type=DataType.Array,
-			data_format='RootModel'
-		)
+	root = json.loads(json_str)
+	DefinitionApi.from_json_dict(root)
 
 
 def test__complex__array__object_validation():
